@@ -75,6 +75,7 @@ GBdd null_bdd();
    ++++++++++++++++++++++++++++++
 
 GBdd leaf(void* i); // Feuille decoree avec "i"
+GBdd int_leaf(int i); // Feuille decoree avec "(long)i"
 
 	5-3) Creation de noeuds binaires :
    ++++++++++++++++++++++++++++++
@@ -541,6 +542,7 @@ public :
 	friend GBdd null_bdd();	//Un GBdd non initialise
 
 	friend GBdd leaf(void* i); // Feuille decoree avec "i"
+	friend GBdd int_leaf(int i); // Feuille decoree avec "(long)i"
 
 	friend GBdd idy(int i); // Fonction identite sur la ieme var
 	friend GBdd nidy(int i); // Fonction complement sur la ieme var
@@ -687,6 +689,7 @@ const GBdd& true_bdd();
 const GBdd& false_bdd();
 GBdd null_bdd();	//Un GBdd non initialise
 GBdd leaf(void* i); // Feuille decoree avec "i"
+GBdd int_leaf(int i); // Feuille decoree avec "(long)i"
 GBdd idy(int i); // Fonction identite sur la ieme var
 GBdd nidy(int i); // Fonction complement sur la ieme var
 int compare(const GBdd& t1, const GBdd& t2); // retourne 0 SSI galit
