@@ -51,7 +51,27 @@
 # Load c-stubs, import commands (machine dep.):
 # - for loading/running the 'dro' appli
 # - misc utilities (e.g. timer)
-load $::env(LUSTRE_INSTALL)/tcl/lustubs.so
+# 2026/02 -> check version compat beteen tclsh and lustubs.so
+# - only major version is takenm into account, maybe not a good idea ...
+
+if { [catch {load $::env(LUSTRE_INSTALL)/tcl/lustubs.so} fid] } {
+	global tcl_version
+   puts stderr "Can't not open standard lustubs\n$fid"
+	puts stderr "tcl_version=$tcl_version"
+	set major [lindex [split $tcl_version "."] 0]
+	puts "major=$major"
+	set alt_so "$::env(LUSTRE_INSTALL)/tcl/lustubs.$major.so"
+	if { [file exist $alt_so] } {
+   	puts stderr "Try to open $alt_so"
+		load $alt_so
+	} else { 
+		puts stderr "No stubs arre available for this version of tclsh ($major)"	
+		exit 1
+	}
+}
+#load $::env(LUSTRE_INSTALL)/tcl/lustubs.so
+
+
 # Load ptk lib (machine indep.)
 lappend auto_path $::env(LUSTRE_INSTALL)/tcl
 package require Ptk
@@ -180,7 +200,7 @@ proc luc::_trace_verb_is_on { args } {
       luc::verbose_off
    }
 }
-trace variable luc::Global(std_verb_on) w luc::_trace_verb_is_on
+trace add variable luc::Global(std_verb_on) write luc::_trace_verb_is_on
 
 proc luc::verbose_to { channel } {
 	luc::DBG "luc::verbose_to $channel"
