@@ -28,7 +28,7 @@
 # and always with a patch to implement them. Jean-Francois Moine was 
 # also kind enough to send in some code patches.
 
-package require Tk 8.0
+package require Tk
 package provide combobox 1.06
 
 namespace eval ::combobox {
