@@ -1,13 +1,13 @@
 
 namespace eval icons {}
 
-#puts "icons::lib=$icons::lib"
+#puts "ICONS.TCL -> icons::lib=$icons::lib"
 
 if { ! [info exists icons::lib] } {
 	set icons::lib "icons"
 }
 proc icons::path { f } {
-	return [file join $icons::lib $f]
+	return [file join $::icons::lib $f]
 }
 
 #http://www.softicons.com/toolbar-icons/shimmer-icons-by-creative-freedom/open-icon
