@@ -3,7 +3,7 @@
 #---------------------------------------------------------
 # Internal stuff + basic container and leaves
 #---------------------------------------------------------
-package require Tk 8.6
+package require Tk
 package provide Ptk 0.1
 
 # return ithe full name of 'standard' widget
@@ -697,7 +697,7 @@ proc ptk::confirm_quit { msg } {
 
 variable ptk::aliases
 proc ptk::new_alias { usrkind kind check } {
-	lappend ptk::aliases($usrkind) [list $kind $check] 
+	lappend ::ptk::aliases($usrkind) [list $kind $check] 
 }
 proc ptk::get_aliases { usrkind } {
 	if { [info exists ptk::aliases($usrkind)] } {
